/***************************************************************************
 *            global.c
 *
 *  Tue Dec 21 19:01:27 2004
 *  Copyright  2004  Jean-Pierre Lozi
 *  jean-pierre@lozi.org - http://gtuxball.lozi.org
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>

#include "graphics.h"
#include "element.h"
#include "globals.h"

/* Globals */
int global_game_start_level;
int global_start_level = 0;
int global_start_speed = GAME_INITIAL_SPEED;
int global_feet = 0;
int global_direction = 0;
int global_state = NOT_PLAYING;
double global_speed; 
int global_lives;
Element global_pad = NULL;
Element global_ball = NULL;
Element global_blocks[NUMBER_OF_LINES][NUMBER_OF_COLUMNS];
int global_current_level;
int global_remaining_blocks;
int global_total_blocks;
time_t global_start_time;
long global_diff_time;
time_t global_freeze_game_time;
int global_levels[NUMBER_OF_LEVELS][NUMBER_OF_LINES][NUMBER_OF_COLUMNS]	= {
						/* level 0 */
						{ 
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x04, 0x03, 0x02, 0x01, 0x06, 0x05, 0x00, 0x00},
							{0x03, 0x04, 0x03, 0x02, 0x01, 0x06, 0x05, 0x00},
							{0x02, 0x03, 0x04, 0x03, 0x02, 0x01, 0x06, 0x05},
							{0x01, 0x02, 0x03, 0x04, 0x03, 0x02, 0x01, 0x06},
							{0x06, 0x01, 0x02, 0x03, 0x04, 0x03, 0x02, 0x01},
							{0x05, 0x06, 0x01, 0x02, 0x03, 0x04, 0x03, 0x02},
							{0x00, 0x05, 0x06, 0x01, 0x02, 0x03, 0x04, 0x03}, 
							{0x00, 0x00, 0x05, 0x06, 0x01, 0x02, 0x03, 0x04},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
						},
						/* level 1 */
						{ 
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01}, 
							{0x01, 0x07, 0x02, 0x00, 0x00, 0x02, 0x07, 0x01}, 
							{0x01, 0x02, 0x03, 0x03, 0x03, 0x03, 0x02, 0x01},  
							{0x01, 0x00, 0x03, 0x06, 0x06, 0x03, 0x00, 0x01}, 
							{0x01, 0x00, 0x03, 0x06, 0x06, 0x03, 0x00, 0x01}, 
							{0x01, 0x00, 0x03, 0x06, 0x06, 0x03, 0x00, 0x01}, 
							{0x01, 0x02, 0x03, 0x03, 0x03, 0x03, 0x02, 0x01},
							{0x01, 0x07, 0x02, 0x00, 0x00, 0x02, 0x07, 0x01},	
							{0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01}
						},
						/* level 2 */
						{ 
							{0x02, 0x00, 0x02, 0x00, 0x02, 0x00, 0x02, 0x00}, 
							{0x00, 0x05, 0x00, 0x05, 0x00, 0x05, 0x00, 0x05}, 
							{0x02, 0x00, 0x02, 0x00, 0x02, 0x00, 0x02, 0x00}, 
							{0x00, 0x05, 0x00, 0x05, 0x00, 0x05, 0x00, 0x05},  
							{0x02, 0x00, 0x02, 0x00, 0x02, 0x00, 0x02, 0x00}, 
							{0x00, 0x05, 0x00, 0x05, 0x00, 0x05, 0x00, 0x05}, 
							{0x02, 0x00, 0x02, 0x00, 0x02, 0x00, 0x02, 0x00}, 
							{0x00, 0x05, 0x00, 0x05, 0x00, 0x05, 0x00, 0x05},
							{0x02, 0x00, 0x02, 0x00, 0x02, 0x00, 0x02, 0x00}, 
							{0x00, 0x05, 0x00, 0x05, 0x00, 0x05, 0x00, 0x05}
						},
						/* level 3 */
						{ 
							{0x04, 0x00, 0x06, 0x00, 0x04, 0x00, 0x06, 0x00},
							{0x04, 0x00, 0x06, 0x00, 0x04, 0x00, 0x06, 0x00},
							{0x04, 0x00, 0x06, 0x00, 0x04, 0x00, 0x06, 0x00},
							{0x04, 0x00, 0x06, 0x00, 0x04, 0x00, 0x06, 0x00},
							{0x04, 0x00, 0x06, 0x00, 0x04, 0x00, 0x06, 0x00},
							{0x04, 0x00, 0x06, 0x00, 0x04, 0x00, 0x06, 0x00},
							{0x04, 0x00, 0x06, 0x00, 0x04, 0x00, 0x06, 0x00}, 
							{0x04, 0x00, 0x06, 0x00, 0x04, 0x00, 0x06, 0x00},
							{0x04, 0x00, 0x06, 0x00, 0x04, 0x00, 0x06, 0x00},
							{0x04, 0x05, 0x06, 0x05, 0x04, 0x05, 0x06, 0x05}
						},
						/* level 4 */
						{
							{0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
						},
						/* level 5 */
						{
							{0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04},
							{0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03},
							{0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04},
							{0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03},
							{0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04},
							{0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03},
							{0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04},
							{0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03},
							{0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04},
							{0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03}
						},
						/* level 6 */
						{
							{0x05, 0x00, 0x04, 0x00, 0x05, 0x00, 0x04, 0x00},
							{0x00, 0x05, 0x00, 0x04, 0x00, 0x05, 0x00, 0x04},
							{0x05, 0x00, 0x04, 0x00, 0x05, 0x00, 0x04, 0x00},
							{0x00, 0x05, 0x00, 0x04, 0x00, 0x05, 0x00, 0x04},
							{0x05, 0x00, 0x04, 0x01, 0x01, 0x00, 0x04, 0x00},
							{0x00, 0x05, 0x00, 0x01, 0x01, 0x05, 0x00, 0x04},
							{0x05, 0x00, 0x04, 0x00, 0x05, 0x00, 0x04, 0x00},
							{0x00, 0x05, 0x00, 0x04, 0x00, 0x05, 0x00, 0x04},
							{0x05, 0x00, 0x04, 0x00, 0x05, 0x00, 0x04, 0x00},
							{0x00, 0x05, 0x00, 0x04, 0x00, 0x05, 0x00, 0x04}
						},
						/* level 7 */
						{
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x01, 0x02, 0x01, 0x02, 0x01, 0x02, 0x01, 0x02},
							{0x02, 0x01, 0x02, 0x01, 0x02, 0x01, 0x02, 0x01},
							{0x01, 0x02, 0x01, 0x02, 0x01, 0x02, 0x01, 0x02},
							{0x02, 0x01, 0x02, 0x01, 0x02, 0x01, 0x02, 0x01},
							{0x01, 0x02, 0x01, 0x02, 0x01, 0x02, 0x01, 0x02}
						},
						/* level 8 */
						{
							{0x03, 0x03, 0x00, 0x00, 0x03, 0x03, 0x00, 0x00},
							{0x03, 0x03, 0x00, 0x00, 0x03, 0x03, 0x00, 0x00},
							{0x00, 0x00, 0x04, 0x04, 0x00, 0x00, 0x04, 0x04},
							{0x00, 0x00, 0x04, 0x04, 0x00, 0x00, 0x04, 0x04},
							{0x03, 0x03, 0x00, 0x00, 0x03, 0x03, 0x00, 0x00},
							{0x03, 0x03, 0x00, 0x00, 0x03, 0x03, 0x00, 0x00},
							{0x00, 0x00, 0x04, 0x04, 0x00, 0x00, 0x04, 0x04},
							{0x00, 0x00, 0x04, 0x04, 0x00, 0x00, 0x04, 0x04},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00},
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}
						},
						/* level 10 */
						{ 
							{0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00}, 
							{0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05}, 
							{0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01}, 
							{0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02},  
							{0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03}, 
							{0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04, 0x04}, 
							{0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05, 0x05}, 
							{0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01, 0x01},
							{0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02, 0x02},	
							{0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03, 0x03}
						}};
