/***************************************************************************
 *            graphics.h
 *
 *  Tue Dec 21 15:40:34 2004
 *  Copyright  2004  Jean-Pierre Lozi
 *  jean-pierre@lozi.org - http://gtuxball.lozi.org
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef GRAPHICS_H
#define GRAPHICS_H

#include "game.h"

/* Constants */
#define BACKGROUND_IMAGE_FILE	"pixmaps/background.png"
#define LOGO_IMAGE_FILE         "pixmaps/penguins.png"
#define BOARD_WIDTH				645
#define BOARD_HEIGHT			480
#define PAUSE_ITEM				0
#define END_ITEM				1
#define SOUND_HOST				"localhost"
#define GAME_START_SOUND		"sounds/start-game.wav"
#define PAUSE_SOUND				"sounds/pause.wav"
#define BLOCK_HIT_SOUND			"sounds/block-hit.wav"
#define OTHER_HIT_SOUND			"sounds/other-hit.wav"
#define WON_SOUND				"sounds/won.wav"
#define LOST_SOUND				"sounds/lost.wav"

/* This is the type of function on which graphics_add_timeout can set a
 * timeout. */
typedef int (* Timeout_function)( void );

/* Public functions : */

/* This function initializes the window and starts the event loop. */
extern void graphics_init (int argc, char *argv[]);
/* This function invalidates the whole graphic area. */
extern void graphics_invalidate_all ( void );
/* This function invalidates a part of the graphic area. */
void graphics_invalidate_rect( 	int top_left_x, int top_left_y,
								int bottom_right_x, int bottom_right_y );
/* This function allows to set the active state of a menu item. */
extern void graphics_menu_item_set_active( int item, int active );
/* This function, when called, displays a prompt asking the user's name. */
extern void graphics_ask_name ( char * name );
/* This function shows the "High Scores" dialog box. */
extern void graphics_show_high_scores( void );
/* This function draws the given element. */
extern void graphics_draw_block( int color, int x, int y, int width, int height, void * data );
/* This function draws the ball at the given coordinates (with the given width and
 * height). */
extern void graphics_draw_ball( int x, int y, int width, int height, void * data );
/* This function draws the pad at the given coordinates (with the given width and
 * height). */
extern void graphics_draw_pad( int x, int y, int width, int height, void * data );
/* Calling this function will make the on_timer function called each timeout seconds. */
extern void graphics_add_timeout( int timeout, Timeout_function on_timer );

#endif
